@@ -12,7 +12,6 @@ class Point():
         self.y = othery
         self.z = otherz
 
-
     def mod(self):
     	return pow((self.x ** 2) + (self.y ** 2) + (self.z ** 2), 0.5)
     def dot(self, v):
@@ -113,15 +112,29 @@ class Perimeter():
                 self.points = np.insert(self.points, i+counter+1, points_list)
                 counter += aux
                 aux = 0
+    def remove_by_angle(self,min_angle=np.pi/180):
+        """
+            Remove points that are closer than delta times the mean distance from
+        each other.
+        """
+        aux = self.points
+        counter = 0
+        if self.points[0]==self.points[-1]:
+            correction = 1
+        else:
+            correction = 0
+        for i in range(self.points.shape[0]-correction):
+            va = self.points[i-1] - self.points[i]
+            vb = self.points[i] - self.points[i+1]
+            if np.arccos(va.dot(vb)) < min_angle and np.arccos(va.dot(vb))>0:
+                aux = np.delete(aux,i-counter)
+                counter += 1
+        self.points = aux
     def remove_overlap(self,delta=0.01):
         """
             Remove points that are closer than delta times the mean distance from
         each other.
         """
-        def neighbourhood(p1, p2, mean, delta) -> bool:
-            if (self.points[i] - self.points[j]).mod() <= delta*mean:
-                return True
-            return False
         aux = self.points
         counter = 0
         mean = 0
@@ -134,7 +147,7 @@ class Perimeter():
         mean = mean/(self.points.shape[0]-1-correction)
         for i in range(self.points.shape[0]-correction):
             for j in range(i+1,self.points.shape[0]-correction):
-                if neighbourhood(self.points[i],self.points[j],mean, delta):
+                if (self.points[i] - self.points[j]).mod() <= delta*mean:
                     aux = np.delete(aux,i-counter)
                     counter += 1
         self.points = aux
@@ -394,7 +407,7 @@ class Perimeter():
         '''
             Analogous to flush_to_numpy(), but returns an array of Point()s
         '''
-        perimeter = np.zeros((flushed.shape[0],3))
+        perimeter = np.empty(flushed.shape[0],Point)
         for index,p in enumerate(flushed):
             perimeter[index] = Point(flushed[index,0],flushed[index,1],flushed[index,2])
         return perimeter
@@ -540,6 +553,7 @@ class Surface():
             g1 = self.slices[i].geometric_center()
             g2 = self.slices[i+1].geometric_center()
             t = abs((g2-g1).dot(self.slices[i].area/self.slices[i].area.mod()))
+            #print(f"p1/(N1*t): {p1/self.slices[i].points.shape[0]/t:.2f}\np2/(N2*t): {p2/self.slices[i+1].points.shape[0]/t:.2f}\nt: {t:.2f}".replace(".",","))
             self.area_est += b_area(t,a1,a2,p1,p2)
             self.vol_est += b_vol(t,a1,a2)
     def build_surface(self, close_list=[], start_points={},skipping_cache=0): #implement cache memmory
